
# Slot: has gene


connects an entity associated with one or more genes

URI: [biolink:has_gene](https://w3id.org/biolink/vocab/has_gene)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [has gene or gene product](has_gene_or_gene_product.md)

## Children

 *  [sequence variant➞has gene](sequence_variant_has_gene.md)

## Used by

